summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/tools/altvstime.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/tools/altvstime.cpp')
-rw-r--r--kstars/kstars/tools/altvstime.cpp38
1 files changed, 19 insertions, 19 deletions
diff --git a/kstars/kstars/tools/altvstime.cpp b/kstars/kstars/tools/altvstime.cpp
index 458b467f..4c51a6a4 100644
--- a/kstars/kstars/tools/altvstime.cpp
+++ b/kstars/kstars/tools/altvstime.cpp
@@ -41,10 +41,10 @@
#include "kstarsdatetime.h"
#include "libkdeedu/extdate/extdatetimeedit.h"
-AltVsTime::AltVsTime( TQWidget* parent) :
- KDialogBase( KDialogBase::Plain, i18n( "Altitude vs. Time" ), Close, Close, parent )
+AltVsTime::AltVsTime( TQWidget* tqparent) :
+ KDialogBase( KDialogBase::Plain, i18n( "Altitude vs. Time" ), Close, Close, tqparent )
{
- ks = (KStars*) parent;
+ ks = (KStars*) tqparent;
TQFrame *page = plainPage();
@@ -53,7 +53,7 @@ AltVsTime::AltVsTime( TQWidget* parent) :
View = new AVTPlotWidget( -12.0, 12.0, -90.0, 90.0, page );
View->setMinimumSize( 400, 400 );
- View->setSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding );
+ View->tqsetSizePolicy( TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding );
View->setXAxisType( KStarsPlotWidget::TIME );
View->setYAxisType( KStarsPlotWidget::ANGLE );
View->setShowGrid( false );
@@ -113,7 +113,7 @@ AltVsTime::AltVsTime( TQWidget* parent) :
AltVsTime::~AltVsTime()
{
// no need to delete child widgets, Qt does it all for us
}
void AltVsTime::slotAddSource(void) {
@@ -190,7 +190,7 @@ void AltVsTime::slotAddSource(void) {
avtUI->decBox->TQWidget::setFocus();
}
- View->repaint(false);
+ View->tqrepaint(false);
}
//Use find dialog to choose an object
@@ -201,7 +201,7 @@ void AltVsTime::slotBrowseObject(void) {
processObject( o );
}
- View->repaint();
+ View->tqrepaint();
}
void AltVsTime::processObject( SkyObject *o, bool forceAdd ) {
@@ -307,11 +307,11 @@ void AltVsTime::slotHighlight(void) {
//move input focus to the next logical widget
void AltVsTime::slotAdvanceFocus(void) {
- if ( sender()->name() == TQString( "nameBox" ) ) avtUI->addButton->setFocus();
- if ( sender()->name() == TQString( "raBox" ) ) avtUI->decBox->setFocus();
- if ( sender()->name() == TQString( "decbox" ) ) avtUI->addButton->setFocus();
- if ( sender()->name() == TQString( "longBox" ) ) avtUI->latBox->setFocus();
- if ( sender()->name() == TQString( "latBox" ) ) avtUI->updateButton->setFocus();
+ if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "nameBox" ) ) avtUI->addButton->setFocus();
+ if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "raBox" ) ) avtUI->decBox->setFocus();
+ if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "decbox" ) ) avtUI->addButton->setFocus();
+ if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "longBox" ) ) avtUI->latBox->setFocus();
+ if ( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() == TQString( "latBox" ) ) avtUI->updateButton->setFocus();
}
void AltVsTime::slotClear(void) {
@@ -323,7 +323,7 @@ void AltVsTime::slotClear(void) {
avtUI->decBox->clear();
avtUI->epochName->clear();
View->clearObjectList();
- View->repaint();
+ View->tqrepaint();
}
void AltVsTime::slotClearBoxes(void) {
@@ -400,7 +400,7 @@ void AltVsTime::slotUpdateDateLoc(void) {
o->updateCoords( num );
//update pList entry
- pList.replace( i, (SkyPoint*)o );
+ pList.tqreplace( i, (SkyPoint*)o );
KPlotObject *po = new KPlotObject( "", "white", KPlotObject::CURVE, 1, KPlotObject::SOLID );
for ( double h=-12.0; h<=12.0; h+=0.5 ) {
@@ -437,7 +437,7 @@ void AltVsTime::slotUpdateDateLoc(void) {
setLSTLimits();
slotHighlight();
- View->repaint();
+ View->tqrepaint();
delete num;
}
@@ -468,7 +468,7 @@ void AltVsTime::setLSTLimits(void) {
void AltVsTime::showCurrentDate (void)
{
- KStarsDateTime dt = KStarsDateTime::currentDateTime();
+ KStarsDateTime dt = KStarsDateTime::tqcurrentDateTime();
if ( dt.time() > TQTime( 12, 0, 0 ) ) dt = dt.addDays( 1 );
avtUI->dateBox->setDate( dt.date() );
}
@@ -495,8 +495,8 @@ double AltVsTime::getEpoch (TQString eName)
return epoch;
}
-AVTPlotWidget::AVTPlotWidget( double x1, double x2, double y1, double y2, TQWidget *parent, const char* name )
- : KStarsPlotWidget( x1, x2, y1, y2, parent, name )
+AVTPlotWidget::AVTPlotWidget( double x1, double x2, double y1, double y2, TQWidget *tqparent, const char* name )
+ : KStarsPlotWidget( x1, x2, y1, y2, tqparent, name )
{
//Default SunRise/SunSet values
SunRise = 0.25;
@@ -512,7 +512,7 @@ void AVTPlotWidget::mouseMoveEvent( TQMouseEvent *e ) {
int Xcursor = e->x();
int Ycursor = e->y();
- if ( ! checkRect.contains( e->x(), e->y() ) ) {
+ if ( ! checkRect.tqcontains( e->x(), e->y() ) ) {
if ( e->x() < checkRect.left() ) Xcursor = checkRect.left();
if ( e->x() > checkRect.right() ) Xcursor = checkRect.right();
if ( e->y() < checkRect.top() ) Ycursor = checkRect.top();
@@ -113,7 +113,7 @@ AltVsTime::AltVsTime( TQWidget* parent) :
AltVsTime::~AltVsTime()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
void AltVsTime::slotAddSource(void) {